"""
A python library for working with the speedrun.com API.
This library is intented to make the api eaiser to use, 
by preprocessing the data, and seperating it into specific sub catagories.
"""

from .speedrunapi import *
from speedrunapi.game_data import *
from speedrunapi.user_data import *
from speedrunapi.runs import *
from speedrunapi.levels import *
